import { program, Command } from '@/program.ts';
import path from 'node:path';
import { AssistantInit } from '@/services/init/index.ts';

type InitCommandOptions = {
  path?: string;
};
const Init = new Command('init')
  .description('初始化一个助手客户端，生成配置文件。')
  .option('-p --path <path>', '助手路径，默认为执行命令的目录，如果助手路径不存在则创建。')
  .action((opts: InitCommandOptions) => {
    // 如果path参数存在，检测path是否是相对路径，如果是相对路径，则转换为绝对路径
    if (opts.path && !opts.path.startsWith('/')) {
      opts.path = path.join(process.cwd(), opts.path);
    } else if (opts.path) {
      opts.path = path.resolve(opts.path);
    }
    const configDir = AssistantInit.detectConfigDir(opts.path);
    const assistantInit = new AssistantInit({
      path: configDir,
    });
    assistantInit.init();
  });

program.addCommand(Init);
